@@ -22,6 +22,9 @@
 #include <analitza/variables.h>
 #include <analitza/expression.h>
 
+#include "../src/consolemodel.h"
+
+#include <QSortFilterProxyModel>
 #include <qqml.h>
 #include "pluginsmodel.h"
 
@@ -30,6 +33,8 @@ using namespace Analitza;
 KAlgebraMobile* KAlgebraMobile::s_self=0;
 KAlgebraMobile* KAlgebraMobile::self() { return s_self; }
 
+Q_DECLARE_METATYPE(QSharedPointer<Analitza::Variables>)
+
 KAlgebraMobile::KAlgebraMobile(QObject* parent)
     : QObject(parent), m_functionsModel(0), m_vars(new Analitza::Variables)
 {
@@ -37,7 +42,11 @@ KAlgebraMobile::KAlgebraMobile(QObject* parent)
     s_self=this;
     
     qmlRegisterType<PluginsModel>("org.kde.kalgebra.mobile", 1, 0, "PluginsModel");
+    qmlRegisterType<ConsoleModel>("org.kde.kalgebra.mobile", 1, 0, "ConsoleModel");
+    qmlRegisterType<QSortFilterProxyModel>("org.kde.kalgebra.mobile", 1, 0, "QSortFilterProxyModel");
     qmlRegisterType<QAbstractItemModel>();
+    qmlRegisterUncreatableType<Analitza::Expression>("org.kde.kalgebra.mobile", 1, 0, "Expression", "because");
+    qRegisterMetaType<QSharedPointer<Analitza::Variables>>("QSharedPointer<Analitza::Variables>");
 }
 
 PlotsModel* KAlgebraMobile::functionsModel()
@@ -80,4 +89,4 @@ void KAlgebraMobile::functionModified(const QModelIndex& idxA, const QModelIndex
     } //else TODO: figure out how to control a "rename"
 }
 
-Analitza::Variables* KAlgebraMobile::variables() const { return m_vars; }
+QSharedPointer<Analitza::Variables> KAlgebraMobile::variables() const { return m_vars; }
